/*
 *  MC68HC901 Device description header
 *
 *  Header file for the Motorola 68HC901 Multi Function Peripheral
 *
 *  This file was compiled from the Motorola HC901/UM and
 *  Motorola SBC5206 dBUG monitor source.
 *
 *  Author:
 *    David Fiddes, D.J@fiddes.surfaid.org
 *    http://www.calm.hw.ac.uk/davidf/coldfire/
 *
 *  COPYRIGHT (c) 1989-1998.
 *  On-Line Applications Research Corporation (OAR).
 *  Copyright assigned to U.S. Government, 1994.
 *
 *  The license and distribution terms for this file may be
 *  found in the file LICENSE in this distribution or at
 * 
 *  http://www.OARcorp.com/rtems/license.html.
 * 
 *  $Id: mc68hc901.h,v 1.11 1998/02/19 23:02:02 joel Exp $
 */

#ifndef _MC68HC901_H_
#define _MC68HC901_H_

/***************************************************************************/
/**  Device definitions for the MC68HC901 MFP                             **/

typedef volatile struct
{
  rtems_unsigned8 GPDR; /* General Purpose I/O Data Register*/
  rtems_unsigned8 AER;  /* Active Edge Register             */
  rtems_unsigned8 DDR;  /* Data Direction Register          */
  rtems_unsigned8 IERA; /* Interrupt Enable Register A      */
  rtems_unsigned8 IERB; /* Interrupt Enable Register B      */
  rtems_unsigned8 IPRA; /* Interrupt Pending Register A     */
  rtems_unsigned8 IPRB; /* Interrupt Pending Register B     */
  rtems_unsigned8 ISRA; /* Interrupt In-Service Register A  */
  rtems_unsigned8 ISRB; /* Interrupt In-Service Register B  */
  rtems_unsigned8 IMRA; /* Interrupt Mask Register A        */
  rtems_unsigned8 IMRB; /* Interrupt Mask Register B        */
  rtems_unsigned8 VR;   /* Vector Register                  */
  rtems_unsigned8 TACR; /* Timer A Control Register         */
  rtems_unsigned8 TBCR; /* Timer B Control Register         */
  rtems_unsigned8 TCDCR;  /* Timer C and D Control Register */
  rtems_unsigned8 TADR; /* Timer A Data Register            */
  rtems_unsigned8 TBDR; /* Timer B Data Register            */
  rtems_unsigned8 TCDR; /* Timer C Data Register            */
  rtems_unsigned8 TDDR; /* Timer D Data Register            */
  rtems_unsigned8 SCR;  /* Synchronous Character Register   */
  rtems_unsigned8 UCR;  /* USART Control Register           */
  rtems_unsigned8 RSR;  /* Receiver Status Register         */
  rtems_unsigned8 TSR;  /* Transmitter Status Register      */
  rtems_unsigned8 UDR;  /* USART Data Register              */

} MC68HC901;

#define MC68HC901_GPDR_GPIP7          (0x80)
#define MC68HC901_GPDR_GPIP6          (0x40)
#define MC68HC901_GPDR_GPIP5          (0x20)
#define MC68HC901_GPDR_GPIP4          (0x10)
#define MC68HC901_GPDR_GPIP3          (0x08)
#define MC68HC901_GPDR_GPIP2          (0x04)
#define MC68HC901_GPDR_GPIP1          (0x02)
#define MC68HC901_GPDR_GPIP0          (0x01)

#define MC68HC901_AER_GPIP7_RISE      ( 0x80)
#define MC68HC901_AER_GPIP6_RISE      ( 0x40)
#define MC68HC901_AER_GPIP5_RISE      ( 0x20)
#define MC68HC901_AER_GPIP4_RISE      ( 0x10)
#define MC68HC901_AER_GPIP3_RISE      ( 0x08)
#define MC68HC901_AER_GPIP2_RISE      ( 0x04)
#define MC68HC901_AER_GPIP1_RISE      ( 0x02)
#define MC68HC901_AER_GPIP0_RISE      ( 0x01)
#define MC68HC901_AER_GPIP7_FALL      (~0x80)
#define MC68HC901_AER_GPIP6_FALL      (~0x40)
#define MC68HC901_AER_GPIP5_FALL      (~0x20)
#define MC68HC901_AER_GPIP4_FALL      (~0x10)
#define MC68HC901_AER_GPIP3_FALL      (~0x08)
#define MC68HC901_AER_GPIP2_FALL      (~0x04)
#define MC68HC901_AER_GPIP1_FALL      (~0x02)
#define MC68HC901_AER_GPIP0_FALL      (~0x01)

#define MC68HC901_DDR_GPIP7_INPUT     (~0x80)
#define MC68HC901_DDR_GPIP6_INPUT     (~0x40)
#define MC68HC901_DDR_GPIP5_INPUT     (~0x20)
#define MC68HC901_DDR_GPIP4_INPUT     (~0x10)
#define MC68HC901_DDR_GPIP3_INPUT     (~0x08)
#define MC68HC901_DDR_GPIP2_INPUT     (~0x04)
#define MC68HC901_DDR_GPIP1_INPUT     (~0x02)
#define MC68HC901_DDR_GPIP0_INPUT     (~0x01)
#define MC68HC901_DDR_GPIP7_OUTPUT    ( 0x80)
#define MC68HC901_DDR_GPIP6_OUTPUT    ( 0x40)
#define MC68HC901_DDR_GPIP5_OUTPUT    ( 0x20)
#define MC68HC901_DDR_GPIP4_OUTPUT    ( 0x10)
#define MC68HC901_DDR_GPIP3_OUTPUT    ( 0x08)
#define MC68HC901_DDR_GPIP2_OUTPUT    ( 0x04)
#define MC68HC901_DDR_GPIP1_OUTPUT    ( 0x02)
#define MC68HC901_DDR_GPIP0_OUTPUT    ( 0x01)

#define MC68HC901_VR_VECTOR(a)        ((a)&0xF0)
#define MC68HC901_VR_S                (0x08)

#define MC68HC901_VR_IV_GPI7          (0x0F)
#define MC68HC901_VR_IV_GPI6          (0x0E)
#define MC68HC901_VR_IV_TIMERA        (0x0D)
#define MC68HC901_VR_IV_RCVBUFFULL    (0x0C)
#define MC68HC901_VR_IV_RCVERROR      (0x0B)
#define MC68HC901_VR_IV_XMITBUFEMPTY  (0x0A)
#define MC68HC901_VR_IV_XMITERROR     (0x09)
#define MC68HC901_VR_IV_TIMERB        (0x08)
#define MC68HC901_VR_IV_GPI5          (0x07)
#define MC68HC901_VR_IV_GPI4          (0x06)
#define MC68HC901_VR_IV_TIMERC        (0x05)
#define MC68HC901_VR_IV_TIMERD        (0x04)
#define MC68HC901_VR_IV_GPI3          (0x03)
#define MC68HC901_VR_IV_GPI2          (0x02)
#define MC68HC901_VR_IV_GPI1          (0x01)
#define MC68HC901_VR_IV_GPI0          (0x00)

#define MC68HC901_IERA_GPIP7          (0x80)
#define MC68HC901_IERA_GPIP6          (0x40)
#define MC68HC901_IERA_TIMERA         (0x20)
#define MC68HC901_IERA_RCVBUFFULL     (0x10)
#define MC68HC901_IERA_RCVERROR       (0x08)
#define MC68HC901_IERA_XMITBUFEMPTY   (0x04)
#define MC68HC901_IERA_XMITERROR      (0x02)
#define MC68HC901_IERA_TIMERB         (0x01)

#define MC68HC901_IERB_GPIP5          (0x80)
#define MC68HC901_IERB_GPIP4          (0x40)
#define MC68HC901_IERB_TIMERC         (0x20)
#define MC68HC901_IERB_TIMERD         (0x10)
#define MC68HC901_IERB_GPIP3          (0x08)
#define MC68HC901_IERB_GPIP2          (0x04)
#define MC68HC901_IERB_GPIP1          (0x02)
#define MC68HC901_IERB_GPIP0          (0x01)

#define MC68HC901_IPRA_GPIP7          (0x80)
#define MC68HC901_IPRA_GPIP6          (0x40)
#define MC68HC901_IPRA_TIMERA         (0x20)
#define MC68HC901_IPRA_RCVBUFFULL     (0x10)
#define MC68HC901_IPRA_RCVERROR       (0x08)
#define MC68HC901_IPRA_XMITBUFEMPTY   (0x04)
#define MC68HC901_IPRA_XMITERROR      (0x02)
#define MC68HC901_IPRA_TIMERB         (0x01)

#define MC68HC901_IPRB_GPIP5          (0x80)
#define MC68HC901_IPRB_GPIP4          (0x40)
#define MC68HC901_IPRB_TIMERC         (0x20)
#define MC68HC901_IPRB_TIMERD         (0x10)
#define MC68HC901_IPRB_GPIP3          (0x08)
#define MC68HC901_IPRB_GPIP2          (0x04)
#define MC68HC901_IPRB_GPIP1          (0x02)
#define MC68HC901_IPRB_GPIP0          (0x01)

#define MC68HC901_IMRA_GPIP7          (0x80)
#define MC68HC901_IMRA_GPIP6          (0x40)
#define MC68HC901_IMRA_TIMERA         (0x20)
#define MC68HC901_IMRA_RCVBUFFULL     (0x10)
#define MC68HC901_IMRA_RCVERROR       (0x08)
#define MC68HC901_IMRA_XMITBUFEMPTY   (0x04)
#define MC68HC901_IMRA_XMITERROR      (0x02)
#define MC68HC901_IMRA_TIMERB         (0x01)

#define MC68HC901_IMRB_GPIP5          (0x80)
#define MC68HC901_IMRB_GPIP4          (0x40)
#define MC68HC901_IMRB_TIMERC         (0x20)
#define MC68HC901_IMRB_TIMERD         (0x10)
#define MC68HC901_IMRB_GPIP3          (0x08)
#define MC68HC901_IMRB_GPIP2          (0x04)
#define MC68HC901_IMRB_GPIP1          (0x02)
#define MC68HC901_IMRB_GPIP0          (0x01)

#define MC68HC901_ISRA_GPIP7          (0x80)
#define MC68HC901_ISRA_GPIP6          (0x40)
#define MC68HC901_ISRA_TIMERA         (0x20)
#define MC68HC901_ISRA_RCVBUFFULL     (0x10)
#define MC68HC901_ISRA_RCVERROR       (0x08)
#define MC68HC901_ISRA_XMITBUFEMPTY   (0x04)
#define MC68HC901_ISRA_XMITERROR      (0x02)
#define MC68HC901_ISRA_TIMERB         (0x01)

#define MC68HC901_ISRB_GPIP5          (0x80)
#define MC68HC901_ISRB_GPIP4          (0x40)
#define MC68HC901_ISRB_TIMERC         (0x20)
#define MC68HC901_ISRB_TIMERD         (0x10)
#define MC68HC901_ISRB_GPIP3          (0x08)
#define MC68HC901_ISRB_GPIP2          (0x04)
#define MC68HC901_ISRB_GPIP1          (0x02)
#define MC68HC901_ISRB_GPIP0          (0x01)

#define MC68HC901_TCR_RESET           (0x10)
#define MC68HC901_TCR_MODE_STOP       (0x00)
#define MC68HC901_TCR_MODE_DM_DIV4    (0x01)
#define MC68HC901_TCR_MODE_DM_DIV10   (0x02)
#define MC68HC901_TCR_MODE_DM_DIV16   (0x03)
#define MC68HC901_TCR_MODE_DM_DIV50   (0x04)
#define MC68HC901_TCR_MODE_DM_DIV64   (0x05)
#define MC68HC901_TCR_MODE_DM_DIV100  (0x06)
#define MC68HC901_TCR_MODE_DM_DIV200  (0x07)
#define MC68HC901_TCR_MODE_EVENT_COUNT  (0x08)
#define MC68HC901_TCR_MODE_PWM_DIV4   (0x09)
#define MC68HC901_TCR_MODE_PWM_DIV10  (0x0A)
#define MC68HC901_TCR_MODE_PWM_DIV16  (0x0B)
#define MC68HC901_TCR_MODE_PWM_DIV50  (0x0C)
#define MC68HC901_TCR_MODE_PWM_DIV64  (0x0D)
#define MC68HC901_TCR_MODE_PWM_DIV100 (0x0E)
#define MC68HC901_TCR_MODE_PWM_DIV200 (0x0F)

#define MC68HC901_TCDCR_TC_MODE_STOP      (0x00)
#define MC68HC901_TCDCR_TC_MODE_DM_DIV4   (0x10)
#define MC68HC901_TCDCR_TC_MODE_DM_DIV10  (0x20)
#define MC68HC901_TCDCR_TC_MODE_DM_DIV16  (0x30)
#define MC68HC901_TCDCR_TC_MODE_DM_DIV50  (0x40)
#define MC68HC901_TCDCR_TC_MODE_DM_DIV64  (0x50)
#define MC68HC901_TCDCR_TC_MODE_DM_DIV100 (0x60)
#define MC68HC901_TCDCR_TC_MODE_DM_DIV200 (0x70)

#define MC68HC901_TCDCR_TD_MODE_STOP      (0x00)
#define MC68HC901_TCDCR_TD_MODE_DM_DIV4   (0x01)
#define MC68HC901_TCDCR_TD_MODE_DM_DIV10  (0x02)
#define MC68HC901_TCDCR_TD_MODE_DM_DIV16  (0x03)
#define MC68HC901_TCDCR_TD_MODE_DM_DIV50  (0x04)
#define MC68HC901_TCDCR_TD_MODE_DM_DIV64  (0x05)
#define MC68HC901_TCDCR_TD_MODE_DM_DIV100 (0x06)
#define MC68HC901_TCDCR_TD_MODE_DM_DIV200 (0x07)

#define MC68HC901_UCR_CLK             (0x80)
#define MC68HC901_UCR_CL_8BIT         (0x00)
#define MC68HC901_UCR_CL_7BIT         (0x20)
#define MC68HC901_UCR_CL_6BIT         (0x40)
#define MC68HC901_UCR_CL_5BIT         (0x60)
#define MC68HC901_UCR_ST_SYNC         (0x00)
#define MC68HC901_UCR_ST_ASYNC_1_1    (0x08)
#define MC68HC901_UCR_ST_ASYNC_1_15   (0x10)
#define MC68HC901_UCR_ST_ASYNC_1_2    (0x18)
#define MC68HC901_UCR_PE              (0x04)
#define MC68HC901_UCR_PARITY_NONE     (0x00)
#define MC68HC901_UCR_PARITY_EVEN     (0x02)
#define MC68HC901_UCR_PARITY_ODD      (0x00)

#define MC68HC901_RSR_BF              (0x80)
#define MC68HC901_RSR_OE              (0x40)
#define MC68HC901_RSR_PE              (0x20)
#define MC68HC901_RSR_FE              (0x10)
#define MC68HC901_RSR_FSB             (0x08)
#define MC68HC901_RSR_MCIP            (0x04)
#define MC68HC901_RSR_SS              (0x02)
#define MC68HC901_RSR_RE              (0x01)

#define MC68HC901_TSR_BE              (0x80)
#define MC68HC901_TSR_UE              (0x40)
#define MC68HC901_TSR_AT              (0x20)
#define MC68HC901_TSR_END             (0x10)
#define MC68HC901_TSR_B               (0x08)
#define MC68HC901_TSR_HL_HIGHZ        (0x00)
#define MC68HC901_TSR_HL_LOW          (0x02)
#define MC68HC901_TSR_HL_HIGH         (0x04)
#define MC68HC901_TSR_HL_LOOP         (0x06)
#define MC68HC901_TSR_L               (0x02)
#define MC68HC901_TSR_TE              (0x01)


#endif /* _MC68HC901_H_ */
